@@ -1,16 +1,14 @@
+use 5.006;    # our, pragmas
 use strict;
 use warnings;
 
 package Moose::Meta::Attribute::Custom::Trait::Indexed;
-BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::Indexed::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Moose::Meta::Attribute::Custom::Trait::Indexed::VERSION = '1.0.3';
-}
+
+our $VERSION = '2.000000';
 
 # ABSTRACT: Registration Node for the Indexed Trait.
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 sub register_implementation {
   return 'MooseX::AttributeIndexes::Meta::Attribute::Trait::Indexed';
@@ -22,13 +20,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Moose::Meta::Attribute::Custom::Trait::Indexed - Registration Node for the Indexed Trait.
 
 =head1 VERSION
 
-version 1.0.3
+version 2.000000
 
 =head1 METHODS
 
@@ -52,7 +52,7 @@ Jesse Luehrs <doy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
