@@ -1,29 +1,33 @@
+use 5.006;    # our, pragmas
 use strict;
 use warnings;
 
 package MooseX::AttributeIndexes::Meta::Role::ApplicationToRole;
-BEGIN {
-  $MooseX::AttributeIndexes::Meta::Role::ApplicationToRole::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $MooseX::AttributeIndexes::Meta::Role::ApplicationToRole::VERSION = '1.0.3';
-}
-use Moose::Role;
+
+our $VERSION = '2.000000';
+
+# ABSTRACT: Give a role indexable attributes
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose::Role qw( around );
 
 around apply => sub {
   my $orig = shift;
   my $self = shift;
-  my ( $role1, $role2 ) = @_;
+  my ( $consumee, $consumer ) = @_;
 
-  $role2 = Moose::Util::MetaRole::apply_metaroles(
-    for            => $role2,
+  # applying $consumee to $consumer, $consumee has AttributeIndexes.
+  # -> $consumer inherits indexable attributes.
+  $consumer = Moose::Util::MetaRole::apply_metaroles(
+    for            => $consumer,
     role_metaroles => {
       application_to_class => [ 'MooseX::AttributeIndexes::Meta::Role::ApplicationToClass', ],
       application_to_role  => [ 'MooseX::AttributeIndexes::Meta::Role::ApplicationToRole', ],
-    }
+    },
   );
 
-  $self->$orig( $role1, $role2 );
+  $self->$orig( $consumee, $consumer );
 };
 
 no Moose::Role;
@@ -34,13 +38,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::AttributeIndexes::Meta::Role::ApplicationToRole
+MooseX::AttributeIndexes::Meta::Role::ApplicationToRole - Give a role indexable attributes
 
 =head1 VERSION
 
-version 1.0.3
+version 2.000000
 
 =head1 AUTHORS
 
@@ -58,7 +64,7 @@ Jesse Luehrs <doy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
